==> baizer_0.5.0.tar.gz: baizer/R/baizer-package.R <==
#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @importFrom dplyr all_of
#' @importFrom dplyr any_of
#' @importFrom dplyr arrange
#' @importFrom dplyr count
#' @importFrom dplyr filter
#' @importFrom dplyr full_join
#' @importFrom dplyr join_by
#' @importFrom dplyr left_join
#' @importFrom dplyr mutate
#' @importFrom dplyr relocate
#' @importFrom dplyr rename
#' @importFrom dplyr select
#' @importFrom grDevices boxplot.stats
#' @importFrom purrr map
#' @importFrom purrr map_dbl
#' @importFrom purrr map_dfr
#' @importFrom purrr map2
#' @importFrom purrr map2_chr
#' @importFrom purrr map2_dbl
#' @importFrom purrr map2_dfr
#' @importFrom rlang :=
#' @importFrom rlang .data
#' @importFrom rlang .env
#' @importFrom rlang current_env
#' @importFrom rlang enexpr
#' @importFrom rlang enexprs
#' @importFrom rlang enquo
#' @importFrom rlang env_clone
#' @importFrom rlang env_coalesce
#' @importFrom rlang expr
#' @importFrom rlang is_expression
#' @importFrom rlang quo_get_env
#' @importFrom rlang quo_get_expr
#' @importFrom rlang quo_is_null
#' @importFrom rlang quo_name
#' @importFrom rlang quo_set_env
#' @importFrom stats IQR
#' @importFrom stats median
#' @importFrom stats runif
#' @importFrom stringr str_c
#' @importFrom stringr str_glue
#' @importFrom tibble as_tibble
#' @importFrom tibble as_tibble_col
#' @importFrom tibble tibble
#' @importFrom tidyr pivot_longer
#' @importFrom tidyr pivot_wider
#' @importFrom utils combn
#' @importFrom utils installed.packages
#' @importFrom utils sessionInfo
## usethis namespace: end
NULL

==> baizer_0.6.0.tar.gz: baizer/R/baizer-package.R <==
#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @importFrom dplyr all_of
#' @importFrom dplyr any_of
#' @importFrom dplyr arrange
#' @importFrom dplyr count
#' @importFrom dplyr filter
#' @importFrom dplyr full_join
#' @importFrom dplyr join_by
#' @importFrom dplyr left_join
#' @importFrom dplyr mutate
#' @importFrom dplyr relocate
#' @importFrom dplyr rename
#' @importFrom dplyr select
#' @importFrom grDevices boxplot.stats
#' @importFrom methods is
#' @importFrom purrr map
#' @importFrom purrr map_chr
#' @importFrom purrr map_dbl
#' @importFrom purrr map_dfc
#' @importFrom purrr map_dfr
#' @importFrom purrr map_lgl
#' @importFrom purrr map2
#' @importFrom purrr map2_chr
#' @importFrom purrr map2_dbl
#' @importFrom purrr map2_dfr
#' @importFrom rlang :=
#' @importFrom rlang .data
#' @importFrom rlang .env
#' @importFrom rlang current_env
#' @importFrom rlang enexpr
#' @importFrom rlang enexprs
#' @importFrom rlang enquo
#' @importFrom rlang env_clone
#' @importFrom rlang env_coalesce
#' @importFrom rlang expr
#' @importFrom rlang is_expression
#' @importFrom rlang quo_get_env
#' @importFrom rlang quo_get_expr
#' @importFrom rlang quo_is_null
#' @importFrom rlang quo_name
#' @importFrom rlang quo_set_env
#' @importFrom stats IQR
#' @importFrom stats median
#' @importFrom stats rnorm
#' @importFrom stats runif
#' @importFrom stringr str_c
#' @importFrom stringr str_detect
#' @importFrom stringr str_glue
#' @importFrom stringr str_replace_all
#' @importFrom stringr str_split
#' @importFrom stringr str_sub
#' @importFrom stringr str_subset
#' @importFrom stringr str_to_upper
#' @importFrom tibble as_tibble
#' @importFrom tibble as_tibble_col
#' @importFrom tibble as_tibble_row
#' @importFrom tibble is_tibble
#' @importFrom tibble tibble
#' @importFrom tidyr pivot_longer
#' @importFrom tidyr pivot_wider
#' @importFrom utils combn
#' @importFrom utils installed.packages
#' @importFrom utils sessionInfo
## usethis namespace: end
NULL
